@@ -1,4 +1,4 @@
-# Copyright (c) 2013, 2014 Stefan Moeding
+# Copyright (c) 2013-2016 Stefan Moeding
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -193,6 +193,10 @@ usl.solve.nlxb <- function(model) {
 #'     expected to be more robust than the \code{nls} method.
 #' }
 #'
+#' The "\code{nlxb}" solver is used as fallback if the "\code{default}"
+#' method is selected and a predictor equal "\code{1}" is missing. A warning
+#' message will be printed in this case.
+#'
 #' The Universal Scalability Law can be expressed with following formula.
 #' \code{C(N)} predicts the relative capacity of the system for a given
 #' load \code{N}:
@@ -209,8 +213,6 @@ usl.solve.nlxb <- function(model) {
 #'   \code{usl} is called.
 #' @param method Character value specifying the method to use. The possible
 #'   values are described under 'Details'.
-#' @param R This parameter is no longer used and will be removed in the next
-#'   version.
 #'
 #' @return An object of class USL.
 #'
@@ -259,7 +261,7 @@ usl.solve.nlxb <- function(model) {
 #'
 #' @export
 #'
-usl <- function(formula, data, method = "default", R) {
+usl <- function(formula, data, method = "default") {
   ## canonicalize the arguments
   formula <- as.formula(formula)
 
@@ -305,15 +307,17 @@ usl <- function(formula, data, method = "default", R) {
   # Choose solver function
   sel <- switch(method, nls=2, nlxb=3, 1)
   usl.solve <- switch(sel, usl.solve.lm, usl.solve.nls, usl.solve.nlxb)
+  
+  # Use method 'nlxb' as fallback if scale factor is missing in data
+  if ((sel == 1)  && (all(frame[regr] != 1))) {
+    usl.solve <- usl.solve.nlxb
+    warning(paste0("'data' has no row where '", regr, "' = 1; ",
+                   "switching method from 'default' to 'nlxb'"))
+  }
 
   # Solve the model for the model frame
   model.result <- usl.solve(model.input)
 
-  # Warn about old parameter usage
-  if (!missing(R)) {
-    warning("parameter 'R' is no longer used")
-  }
-
   # Create object for class USL
   .Object <- new(Class = "USL", call, frame, regr, resp,
                  model.result[['scale.factor']],
